==> ShopifyAPI-8.0.0.tar.gz: ShopifyAPI-8.0.0/shopify/resources/__init__.py <==
from .shop import Shop
from .product import Product
from .cart import Cart
from .checkout import Checkout
from .custom_collection import CustomCollection
from .collect import Collect
from .shipping_address import ShippingAddress
from .billing_address import BillingAddress
from .line_item import LineItem
from .shipping_line import ShippingLine
from .note_attribute import NoteAttribute
from .address import Address
from .option import Option
from .payment_details import PaymentDetails
from .receipt import Receipt
from .rule import Rule
from .tax_line import TaxLine
from .script_tag import ScriptTag
from .application_charge import ApplicationCharge
from .recurring_application_charge import RecurringApplicationCharge
from .usage_charge import UsageCharge
from .asset import Asset
from .theme import Theme
from .currency import Currency
from .customer_saved_search import CustomerSavedSearch
from .customer_group import CustomerGroup
from .customer_invite import CustomerInvite
from .customer import Customer
from .event import Event
from .webhook import Webhook
from .redirect import Redirect
from .province import Province
from .comment import Comment
from .metafield import Metafield
from .article import Article
from .blog import Blog
from .page import Page
from .country import Country
from .refund import Refund
from .fulfillment import Fulfillment
from .fulfillment_service import FulfillmentService
from .carrier_service import CarrierService
from .transaction import Transaction
from .tender_transaction import TenderTransaction
from .image import Image
from .variant import Variant
from .order import Order
from .order_risk import OrderRisk
from .policy import Policy
from .smart_collection import SmartCollection
from .gift_card import GiftCard
from .gift_card_adjustment import GiftCardAdjustment
from .shipping_zone import ShippingZone
from .location import Location
from .draft_order import DraftOrder
from .draft_order_invoice import DraftOrderInvoice
from .report import Report
from .price_rule import PriceRule
from .discount_code import DiscountCode
from .discount_code_creation import DiscountCodeCreation
from .marketing_event import MarketingEvent
from .collection_listing import CollectionListing
from .product_listing import ProductListing
from .resource_feedback import ResourceFeedback
from .storefront_access_token import StorefrontAccessToken
from .inventory_item import InventoryItem
from .inventory_level import InventoryLevel
from .access_scope import AccessScope
from .user import User
from .api_permission import ApiPermission
from .publication import Publication
from .collection_publication import CollectionPublication
from .product_publication import ProductPublication
from .graphql import GraphQL

from ..base import ShopifyResource

==> ShopifyAPI-8.1.0.tar.gz: ShopifyAPI-8.1.0/shopify/resources/__init__.py <==
from .shop import Shop
from .product import Product
from .cart import Cart
from .checkout import Checkout
from .custom_collection import CustomCollection
from .collect import Collect
from .shipping_address import ShippingAddress
from .billing_address import BillingAddress
from .line_item import LineItem
from .shipping_line import ShippingLine
from .note_attribute import NoteAttribute
from .address import Address
from .option import Option
from .payment_details import PaymentDetails
from .receipt import Receipt
from .rule import Rule
from .tax_line import TaxLine
from .script_tag import ScriptTag
from .application_charge import ApplicationCharge
from .recurring_application_charge import RecurringApplicationCharge
from .usage_charge import UsageCharge
from .asset import Asset
from .theme import Theme
from .currency import Currency
from .customer_saved_search import CustomerSavedSearch
from .customer_group import CustomerGroup
from .customer_invite import CustomerInvite
from .customer import Customer
from .event import Event
from .webhook import Webhook
from .redirect import Redirect
from .province import Province
from .comment import Comment
from .metafield import Metafield
from .article import Article
from .blog import Blog
from .page import Page
from .country import Country
from .refund import Refund
from .fulfillment import Fulfillment, FulfillmentOrders
from .fulfillment_service import FulfillmentService
from .carrier_service import CarrierService
from .transaction import Transaction
from .tender_transaction import TenderTransaction
from .image import Image
from .variant import Variant
from .order import Order
from .balance import Balance
from .disputes import Disputes
from .payouts import Payouts
from .transactions import Transactions
from .order_risk import OrderRisk
from .policy import Policy
from .smart_collection import SmartCollection
from .gift_card import GiftCard
from .gift_card_adjustment import GiftCardAdjustment
from .shipping_zone import ShippingZone
from .location import Location
from .draft_order import DraftOrder
from .draft_order_invoice import DraftOrderInvoice
from .report import Report
from .price_rule import PriceRule
from .discount_code import DiscountCode
from .discount_code_creation import DiscountCodeCreation
from .marketing_event import MarketingEvent
from .collection_listing import CollectionListing
from .product_listing import ProductListing
from .resource_feedback import ResourceFeedback
from .storefront_access_token import StorefrontAccessToken
from .inventory_item import InventoryItem
from .inventory_level import InventoryLevel
from .access_scope import AccessScope
from .user import User
from .api_permission import ApiPermission
from .publication import Publication
from .collection_publication import CollectionPublication
from .product_publication import ProductPublication
from .graphql import GraphQL

from ..base import ShopifyResource
